@@ -1,12 +1,12 @@
 package Algorithm::TokenBucket;
 
-use 5.006;
-
-our $VERSION = 0.37;
+use 5.008;
 
 use warnings;
 use strict;
 
+our $VERSION = 0.38;
+
 use Time::HiRes qw/time/;
 
 =head1 NAME
@@ -19,14 +19,14 @@ Algorithm::TokenBucket - Token bucket rate limiting algorithm
 
     # configure a bucket to limit a stream up to 100 items per hour
     # with bursts of 5 items max
-    my $bucket = new Algorithm::TokenBucket 100 / 3600, 5;
+    my $bucket = Algorithm::TokenBucket->new(100 / 3600, 5);
 
     # wait until we are allowed to process 3 items
     until ($bucket->conform(3)) {
         sleep 0.1;
         # do things
     }
- 
+
     # process 3 items because we now can
     process(3);
 
@@ -50,22 +50,23 @@ Algorithm::TokenBucket - Token bucket rate limiting algorithm
     # we're likely to have processed 200 items (and hogged CPU)
 
     Storable::store $bucket, 'bucket.stored';
-    my $bucket1 = new Algorithm::TokenBucket
-            @{Storable::retrieve('bucket.stored')};
+    my $bucket1 =
+        Algorithm::TokenBucket->new(@{Storable::retrieve('bucket.stored')});
 
 =head1 DESCRIPTION
 
-Token Bucket algorithm is a flexible way of imposing a rate limit
+The Token Bucket algorithm is a flexible way of imposing a rate limit
 against a stream of items. It is also very easy to combine several
 rate-limiters in an C<AND> or C<OR> fashion.
 
-Each bucket has a constant memory footprint because the
-algorithm is based on C<information rate>.
-Other rate limiters available on CPAN keep track of I<ALL> incoming
-items in memory. It allows them to be much more accurate.
+Each bucket has a constant memory footprint because the algorithm is based
+on the C<information rate>. Other rate limiters may keep track of
+I<ALL> incoming items in memory. It allows them to be more accurate.
 
-FYI, C<conform>, C<count>, C<information rate>, C<burst size> terms are
-taken from L<http://linux-ip.net/gl/tcng/node62.html> page.
+FYI, the C<conform>, C<count>, C<information rate>, and C<burst size> terms
+are taken from the L<metering primitives|http://linux-ip.net/gl/tcng/node62.html>
+page of the L<Linux Traffic Control - Next Generation|http://linux-ip.net/gl/tcng/>
+system documentation.
 
 =head1 INTERFACE
 
@@ -79,10 +80,10 @@ use fields qw/info_rate burst_size _tokens _last_check_time/;
 
 =item new($$;$$)
 
-The constructor takes as parameters at least C<rate of information> in
-items per second and C<burst size> in items. It can also take current
-token counter and last check time but this usage is mostly intended for
-restoring a saved bucket. See L</state>.
+The constructor requires at least the C<rate of information> in items per
+second and the C<burst size> in items as its input parameters. It can also
+take the current token counter and last check time but this usage is mostly
+intended for restoring a saved bucket. See L</state()>.
 
 =cut
 
@@ -103,9 +104,9 @@ sub _init {
 
 =item state()
 
-This method returns the state of the bucket as a list. Use it for storing purposes.
+Returns the state of the bucket as a list. Use it for storing purposes.
 Buckets also natively support freezing and thawing with L<Storable> by
-providing STORABLE_* callbacks.
+providing C<STORABLE_*> callbacks.
 
 =cut
 
@@ -118,13 +119,13 @@ sub state {
 use constant PACK_FORMAT => "d4";   # "F4" is not 5.6 compatible
 
 sub STORABLE_freeze {
-    my ( $self, $cloning ) = @_;
-    return pack(PACK_FORMAT(),$self->state);
+    my ($self, $cloning) = @_;
+    return pack(PACK_FORMAT(), $self->state);
 }
 
 sub STORABLE_thaw {
-    my ( $self, $cloning, $state ) = @_;
-    return $self->_init(unpack(PACK_FORMAT(),$state));
+    my ($self, $cloning, $state) = @_;
+    return $self->_init(unpack(PACK_FORMAT(), $state));
 }
 
 sub _token_flow {
@@ -132,20 +133,22 @@ sub _token_flow {
 
     my $time = time;
 
-    $self->{_tokens}        += ($time - $self->{_last_check_time}) * $self->{info_rate};
-    $self->{_tokens} > $self->{burst_size} and $self->{_tokens} = $self->{burst_size};
+    $self->{_tokens} +=
+        ($time - $self->{_last_check_time}) * $self->{info_rate};
 
-    $self->{_last_check_time}= $time;
+    if ($self->{_tokens} > $self->{burst_size}) {
+        $self->{_tokens} = $self->{burst_size};
+    }
+
+    $self->{_last_check_time} = $time;
 }
 
 =item conform($)
 
-This method checks if the bucket contains at least I<N> tokens. In that
-case it is allowed to transmit or process I<N> items (not
-exactly right because I<N> can be fractional) from the stream. A bucket never
-conforms to an I<N> greater than C<burst size>.
-
-The method returns a boolean value.
+This method returns true if the bucket contains at least I<N> tokens and
+false otherwise. In the case that it is true, it is allowed to transmit or
+process I<N> items (not exactly right because I<N> can be fractional) from
+the stream. A bucket never conforms to an I<N> greater than C<burst size>.
 
 =cut
 
@@ -160,8 +163,8 @@ sub conform {
 
 =item count($)
 
-This method removes I<N> (or all if there are less than I<N> available) tokens from the bucket.
-Does not return a meaningful value.
+This method removes I<N> (or all if there are fewer than I<N> available)
+tokens from the bucket. It does not return a meaningful value.
 
 =cut
 
@@ -176,13 +179,14 @@ sub count {
 
 =item until($)
 
-This method returns the number of seconds until I<N> tokens can be removed from the bucket.
-It is especially useful in multitasking environments like L<POE> where you
-cannot busy-wait. One can safely schedule the next conform($N) check in until($N)
-seconds instead of checking repeatedly.
+This method returns the number of seconds until I<N> tokens can be removed
+from the bucket. It is especially useful in multitasking environments like
+L<POE> where you cannot busy-wait. One can safely schedule the next
+C<< conform($N) >> check in C<< until($N) >> seconds instead of checking
+repeatedly.
 
-Note that until() does not take into account C<burst size>. This means
-that a bucket will not conform to I<N> even after sleeping for until($N)
+Note that C<until()> does not take into account C<burst size>. This means
+that a bucket will not conform to I<N> even after sleeping for C<< until($N) >>
 seconds if I<N> is greater than C<burst size>.
 
 =cut
@@ -193,12 +197,12 @@ sub until {
 
     $self->_token_flow;
 
-    if ( $self->{_tokens} >= $size ) {
+    if ($self->{_tokens} >= $size) {
         # can conform() right now
         return 0;
     } else {
         my $needed = $size - $self->{_tokens};
-        return ( $needed / $self->{info_rate} );
+        return ($needed / $self->{info_rate});
     }
 }
 
@@ -229,8 +233,8 @@ __END__
 Imagine a rate limiter for a mail sending application. We would like to
 allow 2 mails per minute but no more than 20 mails per hour.
 
-    my $rl1 = new Algorithm::TokenBucket 2/60, 1;
-    my $rl2 = new Algorithm::TokenBucket 20/3600, 10;
+    my $rl1 = Algorithm::TokenBucket->new(2/60, 1);
+    my $rl2 = Algorithm::TokenBucket->new(20/3600, 10);
         # "bursts" of 10 to ease the lag but $rl1 enforces
         # 2 per minute, so it won't flood
 
@@ -244,9 +248,9 @@ allow 2 mails per minute but no more than 20 mails per hour.
     }
 
 Now, let's fix the CPU-hogging example from L</SYNOPSIS> using
-L</until()> method.
+the L</until($)> method.
 
-    my $bucket = new Algorithm::TokenBucket 100 / 3600, 5;
+    my $bucket = Algorithm::TokenBucket->new(100 / 3600, 5);
     my $time = Time::HiRes::time;
     while (Time::HiRes::time - $time < 7200) {  # two hours
         # be bursty
@@ -261,36 +265,49 @@ L</until()> method.
 =head1 BUGS
 
 Documentation lacks the actual algorithm description. See links or read
-the source (there are about 20 lines of sparse perl in several subs).
+the source (there are about 20 lines of sparse Perl in several subs).
 
-until($N) does not return infinity if $N is greater than C<burst
-size>. Sleeping for infinity seconds is both useless and hard to
-debug.
+C<until($N)> does not return infinity if C<$N> is greater than C<burst
+size>. Sleeping for infinity seconds is both useless and hard to debug.
 
 =head1 ACKNOWLEDGMENTS
 
-Yuval Kogman contributed the L</until> method, proper L<Storable> support
+Yuval Kogman contributed the L</until($)> method, proper L<Storable> support
 and other things.
 
-Alexey Shrub contributed the L</get_token_count> method.
+Alexey Shrub contributed the L</get_token_count()> method.
+
+Paul Cochrane contributed various documentation and infrastructure fixes.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (C) 2015 by Alex Kapranoff.
+This software is copyright (C) 2016 by Alex Kapranoff.
 
 This is free software; you can redistribute it and/or modify it under
 the terms GNU General Public License version 3.
 
 =head1 AUTHOR
 
-Alex Kapranoff, E<lt>alex@kapranoff.ru<gt>
+Alex Kapranoff, E<lt>alex@kapranoff.ruE<gt>
 
 =head1 SEE ALSO
 
-http://www.eecs.harvard.edu/cs143/assignments/pa1/,
-http://en.wikipedia.org/wiki/Token_bucket,
-http://linux-ip.net/gl/tcng/node54.html,
-http://linux-ip.net/gl/tcng/node62.html,
-L<Schedule::RateLimit>, L<Algorithm::FloodControl>.
+=over 4
+
+=item https://web.archive.org/web/20050320184218/http://www.eecs.harvard.edu/cs143/assignments/pa1/
+
+=item http://en.wikipedia.org/wiki/Token_bucket
+
+=item http://linux-ip.net/gl/tcng/node54.html
+
+=item http://linux-ip.net/gl/tcng/node62.html
+
+=item L<Schedule::RateLimit>
+
+=item L<Algorithm::FloodControl>
+
+=item L<Object::RateLimiter>
+
+=back
 
 =cut
